lambdacd.stepresults.flatten

Functions to convert a nested step result and transform it into a flat list

Functions to convert a nested step result and transform it into a flat list
raw docstring

lambdacd.stepresults.merge

Functions that can help merge several step results into one

Functions that can help merge several step results into one
raw docstring

lambdacd.stepresults.merge-resolvers

Contains functions that can act as resolvers in merge-two-step-results by returning a merged result of two values if they match or nil if they don't.

Contains functions that can act as resolvers in merge-two-step-results
by returning a merged result of two values if they match or nil if they don't.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries