Control-flow elements for a pipeline: steps that control the way their child-steps are being run.
Control-flow elements for a pipeline: steps that control the way their child-steps are being run.
DEPRECATED: Build-steps that let you work with git repositories.
Use the lambdacd-git library instead.
DEPRECATED: Build-steps that let you work with git repositories. Use the [`lambdacd-git` library](https://github.com/flosell/lambdacd-git) instead.
Build step that waits for manual user interaction.
Example:
> (wait-for-manual-trigger args ctx) ; Blocks, but setting `:trigger-id` in step-result to a random UUID
> (post-id ctx trigger-id trigger-parameters) ; Returns immediately, unblocks the waiting manual trigger
Build step that waits for manual user interaction. Example: ```clojure > (wait-for-manual-trigger args ctx) ; Blocks, but setting `:trigger-id` in step-result to a random UUID > (post-id ctx trigger-id trigger-parameters) ; Returns immediately, unblocks the waiting manual trigger ```
Build step to run scripts in a separate shell process. Needs bash to run.
Build step to run scripts in a separate shell process. Needs `bash` to run.
Predicates over step status.
Predicates over step status.
Functions that implement logic to summarize a list of statuses into a single status.
Commonly used in combination with unify-only-status as a :unify-results-fn to generate the status of a parent step from the statuses of child steps.
These functions might return :unknown if a combination of statuses does not make sense to their scenario.
Functions that implement logic to summarize a list of statuses into a single status. Commonly used in combination with `unify-only-status` as a `:unify-results-fn` to generate the status of a parent step from the statuses of child steps. These functions might return `:unknown` if a combination of statuses does not make sense to their scenario.
Functions that allow you to use LambdaCDs pipeline mechanisms inside a step, i.e. chain several steps together:
(defn some-step [args ctx]
(chaining args ctx
(shell/bash injected-ctx "/ " "echo hello ")
(shell/bash injected-ctx "/ " "echo world ")))
(defn some-step-with-error-handling [args ctx]
(always-chaining args ctx
(run-tests injected-args injected-ctx)
(if (= :failure (:status injected-args))
(publish-test-failures injected-args injected-ctx))))
Functions that allow you to use LambdaCDs pipeline mechanisms inside a step, i.e. chain several steps together:
```clojure
(defn some-step [args ctx]
(chaining args ctx
(shell/bash injected-ctx "/ " "echo hello ")
(shell/bash injected-ctx "/ " "echo world ")))
(defn some-step-with-error-handling [args ctx]
(always-chaining args ctx
(run-tests injected-args injected-ctx)
(if (= :failure (:status injected-args))
(publish-test-failures injected-args injected-ctx))))
```Functions that help in adding the ability for a step to be killed.
Functions that help in adding the ability for a step to be killed.
Functions that support build steps in dealing with metadata
Functions that support build steps in dealing with metadata
Functions and macros that simplify dealing with a steps user readable output (:out). Two approaches are provided:
The printer approach that gives full control over what will be provided as output and the capture-output-approach that just redirects all stdout.
Functions and macros that simplify dealing with a steps user readable output (`:out`). Two approaches are provided: The _printer_ approach that gives full control over what will be provided as output and the `capture-output`-approach that just redirects all stdout.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |