Build step that waits for manual user interaction.
Example:
> (wait-for-manual-trigger args ctx) ; Blocks, but setting `:trigger-id` in step-result to a random UUID
> (post-id ctx trigger-id trigger-parameters) ; Returns immediately, unblocks the waiting manual trigger
Build step that waits for manual user interaction. Example: ```clojure > (wait-for-manual-trigger args ctx) ; Blocks, but setting `:trigger-id` in step-result to a random UUID > (post-id ctx trigger-id trigger-parameters) ; Returns immediately, unblocks the waiting manual trigger ```
(parameterized-trigger parameter-config ctx)Same as wait-for-manual-trigger but also sets metadata that instructs a supporting UI to ask the user for parameters
that will be sent and returned.
Example:
> (parameterized-trigger {:version {:desc "version to deploy"}} ctx) ; blocks until post-id is called
{:status :success
:version {:version "some-version"}}
> (post-id ctx trigger-id {:version "some-version"})
Same as `wait-for-manual-trigger` but also sets metadata that instructs a supporting UI to ask the user for parameters
that will be sent and returned.
Example:
```clojure
> (parameterized-trigger {:version {:desc "version to deploy"}} ctx) ; blocks until post-id is called
{:status :success
:version {:version "some-version"}}
> (post-id ctx trigger-id {:version "some-version"})
```
(post-id ctx id trigger-parameters)Entrypoint for UI and others to release a waiting trigger identified by an ID.
Entrypoint for UI and others to release a waiting trigger identified by an ID.
(wait-for-manual-trigger _ ctx & _)Build step that waits for someone to trigger a build manually, usually by clicking a button in a UI that supports it.
Build step that waits for someone to trigger a build manually, usually by clicking a button in a UI that supports it.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |