Build step to run scripts in a separate shell process. Needs bash to run.
Build step to run scripts in a separate shell process. Needs `bash` to run.
(bash ctx cwd & optional-env-and-commands)step that executes commands in a bash. arguments are the working-directory and at least one command to execute returns stdout and stderr as :out value, the exit code as :exit and succeeds if exit-code was 0
step that executes commands in a bash. arguments are the working-directory and at least one command to execute returns stdout and stderr as :out value, the exit code as :exit and succeeds if exit-code was 0
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |