Predicates over step status.
Predicates over step status.
Functions that implement logic to summarize a list of statuses into a single status.
Commonly used in combination with unify-only-status as a :unify-results-fn to generate the status of a parent step from the statuses of child steps.
These functions might return :unknown if a combination of statuses does not make sense to their scenario.
Functions that implement logic to summarize a list of statuses into a single status. Commonly used in combination with `unify-only-status` as a `:unify-results-fn` to generate the status of a parent step from the statuses of child steps. These functions might return `:unknown` if a combination of statuses does not make sense to their scenario.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |