lambdacd.ui.api

REST-API into the current state, structure and history of the pipeline for use by the UI.

REST-API into the current state, structure and history of the pipeline for use by the UI.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries