REST-API into the current state, structure and history of the pipeline for use by the UI.
REST-API into the current state, structure and history of the pipeline for use by the UI.
(rest-api {pipeline-def :pipeline-def ctx :context})Returns a ring-handler offering a rest-api for the UI.
Returns a ring-handler offering a rest-api for the UI.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |