lambdacd.util.internal.temp


create-temp-dirclj

(create-temp-dir)
(create-temp-dir parent)
source

create-temp-fileclj

(create-temp-file)
source

temp-prefixclj

source

with-tempcljmacro

(with-temp f & body)

evaluates the body, then deletes the given file or directory. returns the result of the evaluation of the body

evaluates the body, then deletes the given file or directory.
returns the result of the evaluation of the body
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries